CreatePaymentTransactionResponse class final

Response returned after creating a payment transaction.

Constructors

CreatePaymentTransactionResponse({required int id, required int apiKeyConfigurationId, String? projectCode, String? currency, int? customerInformationId, String? customerInformationName, String? customerPayingPhoneNumber, String? customerPayingAccountNumber, String? customerPayingExpire, String? customerPayingCvv, DateTime? createdAt, int? createdBy, required bool isDeleted})
Creates a parsed create-transaction response.
const
CreatePaymentTransactionResponse.fromJson(Map<String, dynamic> json)
Parses a create-transaction response from JSON.
factory

Properties

apiKeyConfigurationId int
Resolved API key configuration used for this transaction.
final
createdAt DateTime?
UTC timestamp when the transaction was created.
final
createdBy int?
User ID of the actor that created the transaction.
final
currency String?
Currency code stored on the transaction.
final
customerInformationId int?
Customer identifier in the calling system.
final
customerInformationName String?
Customer display name.
final
customerPayingAccountNumber String?
Card or account number used for payment.
final
customerPayingCvv String?
Card CVV when provided.
final
customerPayingExpire String?
Card expiry value when provided.
final
customerPayingPhoneNumber String?
Phone number used for payment.
final
hashCode int
The hash code for this object.
no setterinherited
id int
Payment transaction ID.
final
isDeleted bool
Whether the transaction has been soft-deleted.
final
projectCode String?
Project code associated with the transaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited