ProjectPaymentWay class final

A single payment way available for a project.

Constructors

ProjectPaymentWay({required int apiKeyConfigurationId, String? package, double? minCurrency, double? maxCurrency, required int projectApiKeyId, required bool isDefault, required int priorityOrder, required String projectApiKeyStatus, required int apiKeyId, required String apiKeyName, String? apiKeyCode, required String apiKeyStatus, int? paymentProviderId, String? paymentProviderName, String? paymentProviderCode, required int paymentTypeOptionId, required String paymentTypeOptionName, required String paymentTypeOptionCode, required int paymentTypeId, required String paymentTypeName, required String paymentTypeCode})
Creates a project payment way.
const
ProjectPaymentWay.fromJson(Map<String, dynamic> json)
Parses a project payment way from JSON.
factory

Properties

apiKeyCode String?
API key code.
final
apiKeyConfigurationId int
API key configuration ID used when creating transactions.
final
apiKeyId int
API key ID.
final
apiKeyName String
API key display name.
final
apiKeyStatus String
Status of the API key.
final
hashCode int
The hash code for this object.
no setterinherited
isDefault bool
Whether this is the default payment way for the project.
final
maxCurrency double?
Maximum allowed payment amount.
final
minCurrency double?
Minimum allowed payment amount.
final
package String?
Package name for this payment way.
final
paymentProviderCode String?
Payment provider code.
final
paymentProviderId int?
Linked payment provider ID when available.
final
paymentProviderName String?
Payment provider display name.
final
paymentTypeCode String
Parent payment type code.
final
paymentTypeId int
Parent payment type ID.
final
paymentTypeName String
Parent payment type display name.
final
paymentTypeOptionCode String
Payment type option code — use with CreatePaymentTransactionRequest.
final
paymentTypeOptionId int
Payment type option ID — use with CreatePaymentTransactionRequest.
final
paymentTypeOptionName String
Payment type option display name.
final
priorityOrder int
Priority order when multiple ways are configured.
final
projectApiKeyId int
Linked project API key ID.
final
projectApiKeyStatus String
Status of the project API key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited