PaymentTransactionsService class final
Payment transaction fetch API operations.
Wraps the Universal Subscription System endpoints:
| Method | HTTP | Route |
|---|---|---|
| getTransactionList | POST | /api/paymenttransactions/gettransactionlist |
| getTransactionDetails | GET | /api/paymenttransactions/gettransactiondetails/{id} |
Constructors
- PaymentTransactionsService(UssHttpClient _http)
-
Creates the payment transactions service.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getTransactionDetails(
int id) → Future< PaymentTransactionDetails> -
Fetches full payment transaction details by
id. -
getTransactionList(
PaymentTransactionListRequest request) → Future< PagedResult< PaymentTransactionListItem> > - Fetches a paginated list of payment transactions for a customer.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited